@@ -23,23 +23,31 @@ pacman --noconfirm -S --needed \
     mingw-w64-$MSYS2_ARCH-libffi \
     mingw-w64-$MSYS2_ARCH-pkg-config \
     mingw-w64-$MSYS2_ARCH-cairo \
-    mingw-w64-$MSYS2_ARCH-pcre \
+    mingw-w64-$MSYS2_ARCH-pcre2 \
     mingw-w64-$MSYS2_ARCH-zlib \
     mingw-w64-$MSYS2_ARCH-gettext
 
 export CCACHE_BASEDIR="${CI_PROJECT_DIR}"
 export CCACHE_DIR="${CCACHE_BASEDIR}/_ccache"
 
-pip3 install --upgrade --user meson==0.58.2 flake8 mypy==0.931 types-Markdown
+pip3 install --upgrade --user meson==0.60 flake8 mypy==0.931 types-Markdown
 export PATH="$HOME/.local/bin:$PATH"
 
-export CFLAGS="-Werror"
-meson -Dcairo=enabled -Ddoctool=enabled --buildtype debug _build
-cd _build
-ninja
+meson setup \
+        -Dwerror=true \
+        -Dglib:werror=false \
+        -Dcairo=enabled \
+        -Ddoctool=enabled \
+        --buildtype debug \
+        _build
 
-meson test --print-errorlogs --suite=gobject-introspection --no-suite=glib
-cd ..
+meson compile -C _build
+
+meson test \
+        --print-errorlogs \
+        --suite=gobject-introspection \
+        --no-suite=glib \
+        -C _build
 
 python3 -m flake8 --count
 python3 -m mypy _build
